flutter_bullet_dots library

Classes

BulletDot
A simple customizable bullet dot widget
BulletList
A simple bullet list widget
BulletListItem
A bullet list item with custom bullet dot and content
CustomBulletList
A bullet list with custom bullet dots for each item
HexagonPainter
Custom painter for hexagon shape
TrianglePainter
Custom painter for triangle shape

Enums

BulletShape
Available bullet shapes